Module `ligo.skymap.moc`
========================
.. module:: ligo.skymap.moc

This module provides functions for manipulating HEALPix datasets in the NUNIQ
ordering scheme.

.. autofunction:: nest2uniq
.. autofunction:: uniq2nest
.. autofunction:: uniq2order
.. autofunction:: uniq2pixarea
.. autofunction:: rasterize
